#!/usr/bin/env python

from __future__ import division
from __future__ import print_function

import pygame
import py2stl
import wire3d

from math import radians

SCREENW = 800
SCREENH = 600
CENTERX = SCREENW // 2
CENTERY = SCREENH // 2

DARK = (20, 12, 28)
LIGHT = (222, 238, 214)

#box = wire3d.Shape.make_from(py2stl.box().rotateX(3.141592/6))

def make_tree():
	tree = wire3d.Group()
	tree += wire3d.Shape.make_from(
		py2stl.cylinder().translateZ(1).scale(0.2, 0.2, 1))
	tree += wire3d.Shape.make_from(
		py2stl.cone().translateZ(1).scaleZ(1.5).translateZ(2))
	return tree

house = wire3d.Group()
house += wire3d.Shape.make_from(py2stl.box().translateZ(1))
house += wire3d.Shape.make_from(
	py2stl.cone(2, 1, 4).translateZ(3).scale(2, 2, 1).rotateZ(radians(45)))

plateau = wire3d.Group()
plateau += wire3d.Shape.make_from(py2stl.disc().scale(5, 5, 1))
plateau += make_tree().translate(3, 1, 0)
plateau += make_tree().translate(-1, -2, 0)
plateau += make_tree().translate(-3, 3, 0)
plateau += house.scale(0.5, 0.5, 0.5)

#camera = wire3d.Camera(0, 2.5, -12, SCREENH)
camera = wire3d.Camera(0, 2.5, -5, SCREENH)

pygame.init()

screen = pygame.display.set_mode((SCREENW, SCREENH))
pygame.display.set_caption("Stereo Imagination")
pygame.event.set_blocked(pygame.MOUSEMOTION)

font_name = pygame.font.get_default_font()
hud_font = pygame.font.SysFont(font_name, SCREENH // 20)

clock = pygame.time.Clock()

def renderer(x1, y1, x2, y2):
	x1 += CENTERX
	y1 = CENTERY - y1
	x2 += CENTERX
	y2 = CENTERY - y2
	pygame.draw.line(screen, LIGHT, (x1, y1), (x2, y2))

while True:
	clock.tick(200)
	
	ev = pygame.event.poll()
	if ev.type == pygame.QUIT:
		break
	elif ev.type == pygame.KEYUP:
		if ev.key == pygame.K_ESCAPE:
			break
	
	screen.fill(DARK)
	plateau.render_through(camera, renderer)
	plateau.rotateZ(0.01)

	try:
		fps = int(round(clock.get_fps()))
	except OverflowError as e:
		fps = 0
	fps_text = hud_font.render(str(fps), False, LIGHT)
	#fps_pos = fps_text.get_rect(midbottom = MID_BOTTOM)
	screen.blit(fps_text, fps_text.get_rect())

	pygame.display.flip()
