#!/usr/bin/env python3

from __future__ import division
from __future__ import print_function

import pygame
import py2stl
import wire3d

from math import radians

SCREENW = 800
SCREENH = 600
CENTERX = SCREENW // 2
CENTERY = SCREENH // 2

DARK = (20, 12, 28)
LIGHT = (222, 238, 214)

plateau = wire3d.Group()
#with open("samples/shapefiles/plateau.stl") as f:
with open("media/retro-suborbital.stl") as f:
	parser = wire3d.STLparser(f)
	s = wire3d.Shape()
	while parser.parse_solid(s):
		plateau += s
		s = wire3d.Shape()

#camera = wire3d.Camera(0, 2.5, -12, SCREENH)
camera = wire3d.Camera(0, 250, -2000, SCREENH)

pygame.init()

screen = pygame.display.set_mode((SCREENW, SCREENH))
pygame.display.set_caption("Stereo Imagination")
pygame.event.set_blocked(pygame.MOUSEMOTION)

font_name = pygame.font.get_default_font()
hud_font = pygame.font.SysFont(font_name, SCREENH // 20)

clock = pygame.time.Clock()

def renderer(x1, y1, x2, y2):
	x1 += CENTERX
	y1 = CENTERY - y1
	x2 += CENTERX
	y2 = CENTERY - y2
	pygame.draw.line(screen, LIGHT, (x1, y1), (x2, y2))

while True:
	clock.tick(200)
	
	ev = pygame.event.poll()
	if ev.type == pygame.QUIT:
		break
	elif ev.type == pygame.KEYUP:
		if ev.key == pygame.K_ESCAPE:
			break
	
	screen.fill(DARK)
	plateau.render_through(camera, renderer)
	plateau.rotateZ(0.01)

	try:
		fps = int(round(clock.get_fps()))
	except OverflowError as e:
		fps = 0
	fps_text = hud_font.render(str(fps), False, LIGHT)
	#fps_pos = fps_text.get_rect(midbottom = MID_BOTTOM)
	screen.blit(fps_text, fps_text.get_rect())

	pygame.display.flip()
